# coding=utf-8
import json

from django.contrib.auth.models import User
from django.test import Client
from django.test import TestCase
from django.urls import reverse

from web.tests.functions import create_worker


class TestApi(TestCase):
    def setUp(self):
        self.client = Client()
        username = 'piotr'
        password = 'top_secret'
        self.user = User.objects.create_user(
            username=username, email='jacob@bla', password=password)
        self.worker = create_worker(self.user)
        self.client.login(username=username, password=password)

    def test_specializations(self):
        specialization_name = "some spec"

        response = self.client.get(reverse('web.api.specializations'))
        self.assertEqual(response.status_code, 200)

        specializations = json.loads(response.content)['specializations']

        self.assertFalse(specialization_name in specializations)

        self.worker.specialization = specialization_name
        self.worker.save()

        response = self.client.get(reverse('web.api.specializations'))
        specializations = json.loads(response.content)['specializations']

        self.assertTrue(specialization_name in specializations)

    def test_units(self):
        unit_name = "some unit"

        response = self.client.get(reverse('web.api.units'))
        self.assertEqual(response.status_code, 200)

        units = json.loads(response.content)['units']

        self.assertFalse(unit_name in units)

        self.worker.unit = unit_name
        self.worker.save()

        response = self.client.get(reverse('web.api.units'))
        units = json.loads(response.content)['units']

        self.assertTrue(unit_name in units)
