from django.shortcuts import redirect, get_object_or_404

from . import wrap_response
from ..forms import ContactAttemptForm, ContactAttemptEditForm
from ..models import Subject, ContactAttempt


def contact_add(request, subject_id):
    subject = get_object_or_404(Subject, id=subject_id)
    if request.method == 'POST':
        form = ContactAttemptForm(request.POST, user=request.user, subject=subject)
        form.instance.subject_id = subject_id
        if form.is_valid():
            form.save()
            if 'from_appointment' in request.GET:
                return redirect('web.views.appointment_edit', id=request.GET.get('from_appointment', ''))
            else:
                return redirect('web.views.subject_edit', id=subject_id)
    else:
        form = ContactAttemptForm(user=request.user, subject=subject)

    return wrap_response(request, 'contact_attempt/add.html',
                         {'form': form, 'subject_id': subject_id})


def contact_edit(request, subject_id, contact_attempt_id):
    contact_attempt = get_object_or_404(ContactAttempt, id=contact_attempt_id)
    if request.method == 'POST':
        form = ContactAttemptEditForm(request.POST, instance=contact_attempt, user=request.user, )
        if form.is_valid():
            form.save()
            if 'from_appointment' in request.GET:
                return redirect('web.views.appointment_edit', id=request.GET.get('from_appointment', ''))
            else:
                return redirect('web.views.subject_edit', id=contact_attempt.subject.id)
    else:
        form = ContactAttemptEditForm(instance=contact_attempt, user=request.user)

    return wrap_response(request, 'contact_attempt/edit.html', {'form': form, 'subject_id': subject_id})
